@@ -34,6 +34,13 @@ class AlreadyExistsException(GitException):
     pass
 
 
+class DoesNotExistException(GitException):
+    """
+    Raised when something does not exist e.g. tag
+    """
+    pass
+
+
 class NoLogsException(GitException):
     """
     Raised when a repository has no logs available
