@@ -1,8 +1,9 @@
 """
-Methods for using the git log command
+Methods for using the 'log' command
 """
 import re
 import subprocess
+from collections.abc import Iterator
 from datetime import datetime
 from pathlib import Path
 from typing import Optional
@@ -15,19 +16,21 @@ from .exceptions import (GitException, NoCommitsException, NoLogsException,
 __all__ = ["get_logs"]
 
 
-def __process_log(stdout_line: str):
+def __process_log(stdout_line: str) -> Log:
     parts = stdout_line.split(";;")
-    if len(parts) != 4:
-        raise ValueError("invalid log line: {stdout_line}")
+    if len(parts) != 6:
+        raise ValueError(f"invalid log line: {stdout_line}")
     return Log(
         parts[0],
         parts[1],
-        datetime.fromisoformat(parts[2]),
-        parts[3]
+        parts[2],
+        parts[3],
+        datetime.fromisoformat(parts[4]),
+        parts[5],
     )
 
 
-def __process_logs(stdout: str):
+def __process_logs(stdout: str) -> Iterator[Log]:
     log_lines = stdout.strip().split("\n")
     return map(__process_log, log_lines)
 
@@ -37,7 +40,7 @@ def get_logs(
         branch: Optional[str] = None,
         max_number: Optional[int] = None,
         since: Optional[datetime] = None,
-        until: Optional[datetime] = None):
+        until: Optional[datetime] = None) -> Iterator[Log]:
     """
     Generate git logs from a repo
 
@@ -62,7 +65,8 @@ def get_logs(
         args.append(f"--since={since.isoformat()}")
     if until is not None:
         args.append(f"--until={until.isoformat()}")
-    args.append("--pretty=%H;;%ae;;%cI;;%s")
+    # formats: https://git-scm.com/docs/pretty-formats
+    args.append("--pretty=%H;;%P;;%ae;;%an;;%cI;;%s")
 
     process_status = subprocess.run(
         args,
